summaryrefslogtreecommitdiffstats
path: root/bibletime/frontend/keychooser/ckeychooserwidget.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'bibletime/frontend/keychooser/ckeychooserwidget.cpp')
-rw-r--r--bibletime/frontend/keychooser/ckeychooserwidget.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/bibletime/frontend/keychooser/ckeychooserwidget.cpp b/bibletime/frontend/keychooser/ckeychooserwidget.cpp
index 01a7b37..25b43f2 100644
--- a/bibletime/frontend/keychooser/ckeychooserwidget.cpp
+++ b/bibletime/frontend/keychooser/ckeychooserwidget.cpp
@@ -147,7 +147,7 @@ void CKeyChooserWidget::reset(TQStringList *list, int index, bool do_emit) {
oldKey = TQString();
// m_comboBox->setUpdatesEnabled(false);
//DON'T REMOVE THE HIDE: Otherwise TQComboBox's tqsizeHint() function won't work properly
m_comboBox->hide();
m_comboBox->clear();
if (list) {
@@ -168,8 +168,8 @@ void CKeyChooserWidget::reset(TQStringList *list, int index, bool do_emit) {
emit changed(m_comboBox->currentItem());
}
- const TQSize dummySize = m_comboBox->tqsizeHint(); //without this function call the combo box won't be properly sized!
- //DON'T REMOVE OR MOVE THE show()! Otherwise TQComboBox's tqsizeHint() function won't work properly!
+ const TQSize dummySize = m_comboBox->sizeHint(); //without this function call the combo box won't be properly sized!
+ //DON'T REMOVE OR MOVE THE show()! Otherwise TQComboBox's sizeHint() function won't work properly!
m_comboBox->show();
// m_comboBox->setFont( m_comboBox->font() );
@@ -147,7 +147,7 @@ void CKeyChooserWidget::reset(TQStringList *list, int index, bool do_emit) {
oldKey = TQString();
// m_comboBox->setUpdatesEnabled(false);
- //DON'T REMOVE THE HIDE: Otherwise TQComboBox's tqsizeHint() function won't work properly
+ //DON'T REMOVE THE HIDE: Otherwise TQComboBox's sizeHint() function won't work properly
m_comboBox->hide();
m_comboBox->clear();